# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['empusa']

package_data = \
{'': ['*']}

install_requires = \
['click', 'python-etcd>=0.4.5,<0.5.0', 'tabulate']

entry_points = \
{'console_scripts': ['empusa = empusa:main']}

setup_kwargs = {
    'name': 'empusa',
    'version': '0.0.3',
    'description': 'Service discovery tool',
    'long_description': '= Empusa\n\n`Empusa` is a trivial tool to build a *service registry* on top of https://etcd.io/[`etcd`]. etcd alone serves as a key/value store, while `empusa` handles the keys, their structure, and values to implement the functionality of a trivial service registry.\n\n\n== Usage\n\nMain command, `empusa`, provides several subcommands, dedicated to different aspects of the service registry operation.\n\n[source,shell]\n....\n$ empusa --help\nUsage: empusa [OPTIONS] COMMAND [ARGS]...\n\nOptions:\n  --etcd-endpoint HOST:PORT  [required]\n  --etcd-protocol TEXT\n  --tree-root TEXT           [required]\n  --help                     Show this message and exit.\n\nCommands:\n  service\n....\n\nTwo bits of information are always required:\n\n* etcd endpoint - host and port where `etcd` listens for client connections. Use `--etcd-endpoint` command-line option, or `EMPUSA_ETCD_ENDPOINT` environment variable.\n+\n[NOTE]\n====\nAt this moment, only the first `etcd` endpoint is used, the rest is ignored. In the future, multiple endpoints will be supported.\n====\n+\n* tree root - path in the key hierarchy under which `empusa` would store it\'s data. `empusa --tree-root /foo` will not read nor modify data `empusa --tree-root /bar` created. Use `--tree-root` command-line option, or `EMPUSA_TREE_ROOT` environment variable.\n\n=== Services\n\nServices come in different types, e.g. HTTP server, SMTP server, Prometheus exporter, internal directory service, and so on. Of each type, usualy multiple instances exist, each having a different name and location. `emposa` treats service types as directories to which each instance, identified by its name, is added together with its location.\n\nTo register a service, execute following command:\n\n[source,shell]\n....\n$ empusa service register --service-type type-of-service --service-name name-of-the-service-instance --service-location baz:1235\n....\n\nIt is possible to use environment variables instead of command-line options:\n\n[source,shell]\n....\n$ EMPUSA_SERVICE_TYPE=type-of-service \\\n  EMPUSA_SERVICE_NAME=name-of-the-service-instance \\\n  EMPUSA_SERVICE_LOCATION=baz:1235 \\\n  empusa service register\n....\n\nThe service can be unregistered as well:\n\n[source,shell]\n....\n$ empusa service unregister --service-type type-of-service --service-name name-of-the-service-instance\n....\n\nA service remains registered until explicitly removed. This may not be always possible, e.g. sometimes the services dies without any chance to perform teardown actions including update to the service registry. To help with this situation, a TTL can be set during registration, in seconds. After that time, the service is removed from the registry.\n\n[source,shell]\n....\n$ empusa service register ... --ttl 30\n....\n\nThe service must then periodicaly update the registry, updating its record and extending the TTL before it expires. You can either have your own scripts to perform this, or you can use `empusa`\'s `--refresh-every` option:\n\n[source,shell]\n....\n$ empusa service register ... --ttl 30 --refresh-every 20\n....\n\nEvery 20 seconds, `empusa` would update the registry, setting the TTL to 30 seconds. Should the service die unexpectedly, `empusa` would not have an opportunity to prolong the TTL, and `etcd` would remove service\'s key.\n\n\n== Try it out\n\n* start an `etcd` instance in Docker container:\n+\n[source,shell]\n....\n$ docker run --rm \\\n             -p 2379:2379 \\\n             -p 2380:2380 \\\n             --volume /tmp/etcd-data.tmp:/etcd-data:Z \\\n             --name etcd-gcr-v3.3.18 \\\n             gcr.io/etcd-development/etcd:v3.3.18 \\\n             /usr/local/bin/etcd \\\n                 --name s1 \\\n                 --data-dir /etcd-data \\\n                 --listen-client-urls http://0.0.0.0:2379 \\\n                 --advertise-client-urls http://0.0.0.0:2379 \\\n                 --listen-peer-urls http://0.0.0.0:2380 \\\n                 --initial-advertise-peer-urls http://0.0.0.0:2380 \\\n                 --initial-cluster s1=http://0.0.0.0:2380 \\\n                 --initial-cluster-token tkn\n....\n+\n* set variables telling `empusa` where to find `etcd`:\n+\n[source,shell]\n....\n$ export EMPUSA_TREE_ROOT=/foo\n$ EMPUSA_ETCD_ENDPOINT=localhost:2379\n....\n\n=== Services\n\n* register a service:\n+\n[source,shell]\n....\n$ empusa service register --service-type dummy-type \\\n                          --service-name dummy-service-1 \\\n                          --service-location baz:1235\nINFO:root:service dummy-service-1 (dummy-type) registered\n....\n+\n* list registered services:\n+\n[source,shell]\n....\n$ empusa service list --service-type dummy-type\n+----------------------------+------------+-------+\n| Service                    | Location   | TTL   |\n|----------------------------+------------+-------|\n| dummy-type/dummy-service-1 | baz:1235   |       |\n+----------------------------+------------+-------+\n....\n* unregister the service:\n+\n[source,shell]\n....\n$ empusa service unregister --service-type dummy-type \\\n                            --service-name dummy-service-1\nINFO:root:service dummy-service-1 (dummy-type) unregistered\n....\n+\n* list registered services:\n+\n[source,shell]\n....\n$ empusa service list --service-type dummy-type\n+-------------------------+------------+-------+\n| Service                 | Location   | TTL   |\n|-------------------------+------------+-------|\n+-------------------------+------------+-------+\n....\n\n`service list` can emit the services in JSON format instead of the table, that should be easier to process by other utilities:\n\n[source,shell]\n....\n$ empusa service list --service-type dummy-type --format json | jq\n[\n  {\n    "service": "/foo/service/dummy-type/dummy-service-1",\n    "location": "baz:1235",\n    "ttl": null\n  }\n]\n....\n\n=== Switches\n\n* set (feature) switch:\n+\n[source,shell]\n....\n$ empusa switch set features/super-cool-feature enabled\nINFO:root:switch features/super-cool-feature set to enabled\n....\n+\n* list switches:\n+\n[source,shell]\n....\n$ empusa switch list\n+-----------------------------+----------+-------+\n| Switch                      | Value    | TTL   |\n|-----------------------------+----------+-------|\n| features/super-cool-feature | enabled  |       |\n+-----------------------------+----------+-------+\n....\n* toggle the switch:\n+\n[source,shell]\n....\n$ empusa switch toggle feature/super-cool-feature\nINFO:root:switch feature/super-cool-feature set to no\n....\n\nAgain, `switch list` can emit the list of switches in JSON format instead of the table.\n',
    'author': 'Milos Prchlik',
    'author_email': 'mprchlik@redhat.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://pypi.org/project/empusa',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
